html, body { color:#000000; font-family:monospace; font-size:12px; line-height:1.42857142857143; }
body { padding:15px 20px 60px 20px; }

h1, h2, h3, h4, h5, h6 { text-transform:uppercase; margin:0; padding:0; margin-bottom:2px; }
h1, .h1 { font-size:22px; }
h2, .h2 { font-size:20px; }
h3, .h3 { font-size:18px; }
h4, .h4 { font-size:16px; }
h5, .h5 { font-size:14px; }
h6, .h6 { font-size:12px; }

ul { list-style-type:none; margin:0; padding: 0 0px 0 30px; }
ul li { margin-top:7px; }
ul li .arrow { font-weight:normal; color:#999999; }

a { color:#000000; text-decoration:none; display:inline-block; }
a:hover { text-decoration:underline; }
a.github { color:#0000CC; }

.separator { color:#CCCCCC; margin:0 10px; font-weight:normal; }

a.pages-admin { font-size:12px; color:#000000; font-weight:bold; text-transform:uppercase; display:inline-block; margin-top:0px; }

.languages-wrapper,
.breadcrumbs-wrapper,
.pages-wrapper,
.routes-wrapper { margin-top:40px; }

.navsy-languages-menu > ul,
.navsy-breadcrumbs > ul,
.navsy-menu > ul,
.navsy-routes > ul { padding:0; margin-top:0px; margin-top:0px; }

.navsy-languages-menu ul li { display:inline-block; }
.navsy-languages-menu ul li::before { content:"|"; padding:0px 7px; color:#CCCCCC; }
.navsy-languages-menu ul li:first-child::before { content:""; padding:0; }
.navsy-languages-menu ul li.active a { font-weight:bold; }
.navsy-languages-menu ul li.active a::before { content:"["; }
.navsy-languages-menu ul li.active a::after { content:"]"; }
.navsy-languages-menu select { margin:10px 0px 5px; }


.navsy-breadcrumbs ul::before { content:"/"; padding:0 7px 0 0; color:#CCCCCC; }
.navsy-breadcrumbs ul li { display:inline-block; }
.navsy-breadcrumbs ul li::before { content:"/"; padding:0 7px; color:#CCCCCC; }
.navsy-breadcrumbs ul li:first-child::before { content:""; padding:0; }
.navsy-breadcrumbs ul li.active { font-weight:bold; }

.navsy-menu ul li > a::after { content:""; display:inline-block; width:6px; height:6px; background-color:#00CC00; border-radius:100%; margin-left:5px; }
.navsy-menu ul li.active > a { font-weight:bold; text-decoration:underline; }
.navsy-menu ul li.active-parent > a { text-decoration:underline; }
.navsy-menu ul li.active-child > a { font-weight:bold; }
.navsy-menu ul li.not-in-menu > a ,
.navsy-menu ul li.not-in-menu > a + ul li > a {}
.navsy-menu ul li.not-in-menu > a::after,
.navsy-menu ul li.not-in-menu > a + ul li > a::after { /*background-color:#CCCC00;*/ opacity:0.3; }
.navsy-menu ul li.not-published > a,
.navsy-menu ul li.not-published > a + ul li > a { text-decoration:line-through; cursor:not-allowed; /*pointer-events:none;*/ }
.navsy-menu ul li.not-published > a::after,
.navsy-menu ul li.not-published > a + ul li > a::after { background-color:#CCCCCC; /*background-color:#CC0000;*/ }
.navsy-menu select { margin:10px 0px 5px; }

.navsy-routes ul li .route { font-size:10px; color:#CCCCCC; margin:2px 0 0 0; padding:0; }
.navsy-routes ul li.active .route { font-weight:normal; color:#000000; }
.navsy-routes ul li .route code { font-weight:normal; font-size:10px; color:#CC00CC; margin-left:7px; }

